@@ -8,14 +8,16 @@ from tests import utils
 # This generated code must be part of an upper block to pass the imports to greater level
 
 _CLASS = Class(name="APIWrapper", inherit=("Sized",))
-_CLASS.add_doc_line("A class that represents a raper for a defined API structure.")
+_CLASS.add_doc_line(
+    "A class that represents a generated client for a defined API structure."
+)
 _CLASS.add_specific_import("collections", "Sized")
 _CLASS.add_specific_import("logging", "Logger")
 
 _SYNTAX = """
 class APIWrapper(Sized,):
     \"\"\"
-    A class that represents a raper for a defined API structure.
+    A class that represents a generated client for a defined API structure.
     \"\"\"
 
     from collections import Sized
